@@ -7,6 +7,7 @@ import json
 from six.moves.urllib.parse import urlencode
 
 import requests
+session = requests.Session()
 
 
 class InfluxDBClient(object):
@@ -63,7 +64,7 @@ class InfluxDBClient(object):
         """
         Write to multiple time series names
         """
-        response = requests.post(
+        response = session.post(
             "{0}/db/{1}/series?u={2}&p={3}".format(
                 self._baseurl,
                 self._database,
@@ -88,7 +89,7 @@ class InfluxDBClient(object):
 
         url_format = "{0}/db/{1}/series?u={2}&p={3}&time_precision={4}"
 
-        response = requests.post(url_format.format(
+        response = session.post(url_format.format(
             self._baseurl,
             self._database,
             self._username,
@@ -176,7 +177,7 @@ class InfluxDBClient(object):
         url_format = "{0}/db/{1}/series?{2}&u={3}&p={4}"
         url_format += "&time_precision={5}&chunked={6}"
 
-        response = requests.get(url_format.format(
+        response = session.get(url_format.format(
             self._baseurl,
             self._database,
             encoded_query,
@@ -208,7 +209,7 @@ class InfluxDBClient(object):
         database: string
             database name
         """
-        response = requests.post("{0}/db?u={1}&p={2}".format(
+        response = session.post("{0}/db?u={1}&p={2}".format(
             self._baseurl,
             self._username,
             self._password),
@@ -230,7 +231,7 @@ class InfluxDBClient(object):
         database: string
             database name
         """
-        response = requests.delete("{0}/db/{1}?u={2}&p={3}".format(
+        response = session.delete("{0}/db/{1}?u={2}&p={3}".format(
             self._baseurl,
             database,
             self._username,
@@ -248,7 +249,7 @@ class InfluxDBClient(object):
 
     # add cluster admin
     # curl -X POST http://localhost:8086/cluster_admins?u=root&p=root \
-    #      -d '{"username": "paul", "password": "i write teh docz"}'
+    #      -d '{"name": "paul", "password": "i write teh docz"}'
 
     # update cluster admin password
     # curl -X POST http://localhost:8086/cluster_admins/paul?u=root&p=root \
@@ -263,7 +264,7 @@ class InfluxDBClient(object):
 
     # add database admin
     # curl -X POST http://localhost:8086/db/site_dev/admins?u=root&p=root \
-    #      -d '{"username": "paul", "password": "i write teh docz"}'
+    #      -d '{"name": "paul", "password": "i write teh docz"}'
 
     # update database admin password
     # curl -X POST http://localhost:8086/db/site_dev/admins/paul?u=root&p=root\
@@ -277,7 +278,7 @@ class InfluxDBClient(object):
         """
         Get list of cluster admins
         """
-        response = requests.get(
+        response = session.get(
             "{0}/cluster_admins?u={1}&p={2}".format(
                 self._baseurl,
                 self._username,
@@ -293,13 +294,13 @@ class InfluxDBClient(object):
         """
         Add cluster admin
         """
-        response = requests.post(
+        response = session.post(
             "{0}/cluster_admins?u={1}&p={2}".format(
                 self._baseurl,
                 self._username,
                 self._password),
             data=json.dumps({
-                'username': new_username,
+                'name': new_username,
                 'password': new_password}),
             headers=self._headers)
 
@@ -313,7 +314,7 @@ class InfluxDBClient(object):
         """
         Update cluster admin password
         """
-        response = requests.post(
+        response = session.post(
             "{0}/cluster_admins/{1}?u={2}&p={3}".format(
                 self._baseurl,
                 username,
@@ -333,7 +334,7 @@ class InfluxDBClient(object):
         """
         Delete cluster admin
         """
-        response = requests.delete("{0}/cluster_admins/{1}?u={2}&p={3}".format(
+        response = session.delete("{0}/cluster_admins/{1}?u={2}&p={3}".format(
             self._baseurl,
             username,
             self._username,
@@ -349,30 +350,24 @@ class InfluxDBClient(object):
         """
         Set user as database admin
         """
-        response = requests.post(
-            "{0}/db/{1}/admins/{2}?u={3}&p={4}".format(
-                self._baseurl,
-                self._database,
-                username,
-                self._username,
-                self._password))
-        if response.status_code == 200:
-            return True
-        else:
-            raise Exception(
-                "{0}: {1}".format(response.status_code, response.content))
+        return self.alter_database_admin(username, True)
 
     def unset_database_admin(self, username):
         """
         Unset user as database admin
         """
-        response = requests.delete(
-            "{0}/db/{1}/admins/{2}?u={3}&p={4}".format(
+        return self.alter_database_admin(username, False)
+
+    def alter_database_admin(self, username, is_admin):
+        response = session.post(
+            "{0}/db/{1}/users/{2}?u={3}&p={4}".format(
                 self._baseurl,
                 self._database,
                 username,
                 self._username,
-                self._password))
+                self._password),
+            data=json.dumps({'admin': is_admin}),
+            headers=self._headers)
         if response.status_code == 200:
             return True
         else:
@@ -428,7 +423,7 @@ class InfluxDBClient(object):
 
     # add database user
     # curl -X POST http://localhost:8086/db/site_dev/users?u=root&p=root \
-    #       -d '{"username": "paul", "password": "i write teh docz"}'
+    #       -d '{"name": "paul", "password": "i write teh docz"}'
 
     # update database user password
     # curl -X POST http://localhost:8086/db/site_dev/users/paul?u=root&p=root \
@@ -441,7 +436,7 @@ class InfluxDBClient(object):
         """
         Get list of database users
         """
-        response = requests.get(
+        response = session.get(
             "{0}/db/{1}/users?u={2}&p={3}".format(
                 self._baseurl,
                 self._database,
@@ -458,14 +453,14 @@ class InfluxDBClient(object):
         """
         Add database user
         """
-        response = requests.post(
+        response = session.post(
             "{0}/db/{1}/users?u={2}&p={3}".format(
                 self._baseurl,
                 self._database,
                 self._username,
                 self._password),
             data=json.dumps({
-                'username': new_username,
+                'name': new_username,
                 'password': new_password}),
             headers=self._headers)
 
@@ -479,7 +474,7 @@ class InfluxDBClient(object):
         """
         Update password
         """
-        response = requests.post(
+        response = session.post(
             "{0}/db/{1}/users/{2}?u={3}&p={4}".format(
                 self._baseurl,
                 self._database,
@@ -502,7 +497,7 @@ class InfluxDBClient(object):
         """
         Delete database user
         """
-        response = requests.delete(
+        response = session.delete(
             "{0}/db/{1}/users/{2}?u={3}&p={4}".format(
                 self._baseurl,
                 self._database,
