@@ -2,8 +2,6 @@
 """
 unit tests
 """
-import json
-
 import requests
 from nose.tools import raises
 from mock import patch
@@ -100,7 +98,10 @@ class TestInfluxDBClient(object):
         cli.remove_scheduled_delete(1)
 
     def test_query(self):
-        expected = """[{"name":"foo","columns":["time","sequence_number","column_one"],"points":[[1383876043,16,"2"],[1383876043,15,"1"],[1383876035,14,"2"],[1383876035,13,"1"]]}]"""
+        expected = ('[{"name":"foo",'
+                    '"columns":["time","sequence_number","column_one"],'
+                    '"points":[[1383876043,16,"2"],[1383876043,15,"1"],'
+                    '[1383876035,14,"2"],[1383876035,13,"1"]]}]')
         with patch.object(session, 'get') as mocked_get:
             mocked_get.return_value = _build_response_object(
                 status_code=200,
